labeltools.label_leaves_in_expr_with_melodic_counterpoint_interval_classes
==========================================================================

.. autofunction:: abjad.tools.labeltools.label_leaves_in_expr_with_melodic_counterpoint_interval_classes.label_leaves_in_expr_with_melodic_counterpoint_interval_classes
   :noindex:
